@@ -11,6 +11,7 @@
 # under the License.
 
 import collections
+import configparser
 import re
 
 from oslo_log import log as logging
@@ -24,18 +25,7 @@ from pycadf import host
 from pycadf import identifier
 from pycadf import resource
 from pycadf import tag
-import six
-from six.moves import configparser
-from six.moves.urllib import parse as urlparse
-
-# NOTE(blk-u): Compatibility for Python 2. SafeConfigParser and
-# SafeConfigParser.readfp are deprecated in Python 3. Remove this when we drop
-# support for Python 2.
-if six.PY2:
-    class _ConfigParser(configparser.SafeConfigParser):
-        read_file = configparser.SafeConfigParser.readfp
-else:
-    _ConfigParser = configparser.ConfigParser
+from urllib import parse as urlparse
 
 
 Service = collections.namedtuple('Service',
@@ -57,10 +47,15 @@ class PycadfAuditApiConfigError(Exception):
 
 
 class ClientResource(resource.Resource):
-    def __init__(self, project_id=None, **kwargs):
+    def __init__(self, project_id=None, request_id=None,
+                 global_request_id=None, **kwargs):
         super(ClientResource, self).__init__(**kwargs)
         if project_id is not None:
             self.project_id = project_id
+        if request_id is not None:
+            self.request_id = request_id
+        if global_request_id is not None:
+            self.global_request_id = global_request_id
 
 
 class KeystoneCredential(credential.Credential):
@@ -81,8 +76,9 @@ class OpenStackAuditApi(object):
 
         if cfg_file:
             try:
-                map_conf = _ConfigParser()
-                map_conf.read_file(open(cfg_file))
+                map_conf = configparser.ConfigParser()
+                with open(cfg_file) as fh:
+                    map_conf.read_file(fh)
 
                 try:
                     default_target_endpoint_type = map_conf.get(
@@ -261,14 +257,19 @@ class OpenStackAuditApi(object):
 
         default_endpoint = None
         for endp in catalog:
+            if not endp['endpoints']:
+                self._log.warning(
+                    'Skipping service %s as it have no endpoints.',
+                    endp['name'])
+                continue
             endpoint_urls = endp['endpoints'][0]
             admin_urlparse = urlparse.urlparse(
                 endpoint_urls.get('adminURL', ''))
             public_urlparse = urlparse.urlparse(
                 endpoint_urls.get('publicURL', ''))
             req_url = urlparse.urlparse(req.host_url)
-            if (req_url.netloc == admin_urlparse.netloc
-                    or req_url.netloc == public_urlparse.netloc):
+            if req_url.port and (req_url.netloc == admin_urlparse.netloc
+                                 or req_url.netloc == public_urlparse.netloc):
                 service_info = self._get_service_info(endp)
                 break
             elif (self._MAP.default_target_endpoint_type and
@@ -292,7 +293,10 @@ class OpenStackAuditApi(object):
                 token=req.environ.get('HTTP_X_AUTH_TOKEN', ''),
                 identity_status=req.environ.get('HTTP_X_IDENTITY_STATUS',
                                                 taxonomy.UNKNOWN)),
-            project_id=req.environ.get('HTTP_X_PROJECT_ID', taxonomy.UNKNOWN))
+            project_id=req.environ.get('HTTP_X_PROJECT_ID', taxonomy.UNKNOWN),
+            request_id=req.environ.get('openstack.request_id'),
+            global_request_id=req.environ.get('openstack.global_request_id'))
+
         target = self.get_target_resource(req)
 
         event = factory.EventFactory().new_event(
